HiddenMarkov

Struct HiddenMarkov 

pub struct HiddenMarkov { /* private fields */ }
Specialized structure for Hidden Markov Model of order 1 The states are identified by ids taken from natural numbers.

Implementations

Source

impl HiddenMarkov

pub fn new( initials: Vec<f64>, transitions: Vec<Vec<f64>>, observation_model: Vec<Vec<f64>>, ) -> Option<HiddenMarkov>

Create a new Hidden Markov Model Please note that:

  • initials should have more then 1 state. Its values should be positive
  • transitions should have exactly #state x #state elements. Values positive
  • observation_model should have #state x #outcomes elements. Values positive

Params:

  • initials - Initial probability for each state
  • transition - Probability of changing state from x_1 to x_2 (state x state)
  • observation_matrix - Probability of generating outcome in each state (state x outcome)

Observation Vec should:

  • Have at least 1 observation
  • Each LabelId should be less then maximum number of observation in HMM model
pub fn map_estimate(&self, observations: Vec<usize>) -> Vec<usize>

Calculate MAP (Maximum a posteriori) using Viterbi algorithm As a input provide list of observations and as a output this function will provide The most probable sequence of states which generates such observations